@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
-@Author: HuangJingCan
-@Date: 2020-11-20 16:16:22
-@LastEditTime: 2020-11-20 16:22:35
-@LastEditors: HuangJingCan
-@Description: appinfo相关
+:Author: HuangJingCan
+:Date: 2020-11-20 16:16:22
+:LastEditTime: 2020-12-25 11:12:49
+:LastEditors: HuangJingCan
+:description: appinfo相关
 """
 from seven_cloudapp.handlers.seven_base import *
 
@@ -13,14 +13,13 @@ from seven_cloudapp.models.db_models.app.app_info_model import *
 
 class GetAppExpireHandler(SevenBaseHandler):
     """
-    @description: 获取小程序是否过期未续费
+    :description: 获取小程序是否过期未续费
     """
     def get_async(self):
         """
-        @description: 获取小程序是否过期未续费
-        @param {*}
-        @return {*}
-        @last_editors: HuangJianYi
+        :description: 获取小程序是否过期未续费
+        :return info
+        :last_editors: HuangJianYi
         """
         app_id = self.get_taobao_param().source_app_id
         now_date = self.get_now_datetime()
