@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
-@Author: CaiYouBin
-@Date: 2020-05-28 14:50:27
-@LastEditTime: 2020-12-24 18:01:21
-@LastEditors: HuangJingCan
-@Description: 商品相关
+:Author: CaiYouBin
+:Date: 2020-05-28 14:50:27
+:LastEditTime: 2021-01-05 14:07:44
+:LastEditors: HuangJingCan
+:description: 商品相关
 """
 from seven_cloudapp.handlers.top_base import *
 
@@ -15,17 +15,17 @@ from seven_cloudapp.models.db_models.recommend.recommend_goods_model import *
 
 class SubmitSkuHandler(SevenBaseHandler):
     """
-    @description: 提交SKU
+    :description: 提交SKU
     """
     @filter_check_params("sku_id")
     def get_async(self):
         """
-        @description: 提交SKU
-        @param user_prize_id：用户中奖信息id
-        @param properties_name：sku属性
-        @param sku_id：sku_id
-        @return {*}
-        @last_editors: HuangJingCan
+        :description: 提交SKU
+        :param user_prize_id：用户中奖信息id
+        :param properties_name：sku属性
+        :param sku_id：sku_id
+        :return 
+        :last_editors: HuangJingCan
         """
         app_id = self.get_taobao_param().source_app_id
         open_id = self.get_taobao_param().open_id
@@ -54,14 +54,14 @@ class SubmitSkuHandler(SevenBaseHandler):
 
 class SkuInfoHandler(TopBaseHandler):
     """
-    @description: 获取SKU信息
+    :description: 获取SKU信息
     """
     def get_async(self):
         """
-        @description: 获取SKU信息
-        @param num_iids：num_iids
-        @return
-        @last_editors: HuangJingCan
+        :description: 获取SKU信息
+        :param num_iids：num_iids
+        :return
+        :last_editors: HuangJingCan
         """
         app_id = self.get_taobao_param().source_app_id
         num_iids = self.get_param("num_iids")
@@ -76,15 +76,15 @@ class SkuInfoHandler(TopBaseHandler):
 
 class GoodsListHandler(TopBaseHandler):
     """
-    @description: 导入商品列表
+    :description: 导入商品列表
     """
     def get_async(self):
         """
-        @description: 导入商品列表
-        @param page_index：页索引
-        @param page_size：页大小
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 导入商品列表
+        :param page_index：页索引
+        :param page_size：页大小
+        :return: 
+        :last_editors: HuangJingCan
         """
         app_id = self.get_taobao_param().source_app_id
         page_index = int(self.get_param("page_index", 0))
@@ -100,19 +100,23 @@ class GoodsListHandler(TopBaseHandler):
 
 class RecommandGoodsHandler(SevenBaseHandler):
     """
-    @description: 获取推荐商品列表
+    :description: 获取推荐商品列表
     """
     @filter_check_params("act_id")
     def get_async(self):
         """
-        @description: 获取推荐商品列表
-        @param act_id：活动id
-        @return: list
-        @last_editors: HuangJianYi
+        :description: 获取推荐商品列表
+        :param act_id：活动id
+        :return: list
+        :last_editors: HuangJianYi
         """
         act_id = int(self.get_param("act_id", 0))
 
-        recommend_goods = RecommendGoodsModel().get_entity("act_id=%s", params=[act_id])
+        if act_id <= 0:
+            return self.reponse_json_error_params()
+
+        recommend_goods = RecommendGoodsModel().get_entity("act_id=%s", params=act_id)
+
         if not recommend_goods:
             self.reponse_json_success([])
         elif recommend_goods.is_release == 0:
