@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
-@Author: HuangJingCan
-@Date: 2020-11-05 10:13:31
-@LastEditTime: 2020-12-24 18:01:04
-@LastEditors: HuangJingCan
-@Description: 奖品相关
+:Author: HuangJingCan
+:Date: 2020-11-05 10:13:31
+:LastEditTime: 2021-01-07 11:46:56
+:LastEditors: HuangJingCan
+:description: 奖品相关
 """
 from seven_cloudapp.handlers.top_base import *
 
@@ -19,18 +19,18 @@ from seven_cloudapp.models.seven_model import PageInfo
 
 class PrizeListHandler(SevenBaseHandler):
     """
-    @description: 奖品列表
+    :description: 奖品列表
     """
     @filter_check_params("act_id")
     def get_async(self):
         """
-        @description:  获取奖品列表
-        @param act_id：活动id
-        @param machine_id：机台id
-        @param page_index：页索引
-        @param page_size：页大小
-        @return: 分页列表信息
-        @last_editors: HuangJingCan
+        :description:  获取奖品列表
+        :param act_id：活动id
+        :param machine_id：机台id
+        :param page_index：页索引
+        :param page_size：页大小
+        :return: 分页列表信息
+        :last_editors: HuangJingCan
         """
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 20))
@@ -47,14 +47,11 @@ class PrizeListHandler(SevenBaseHandler):
 
         act_prize_page_list, total = ActPrizeModel().get_dict_page_list("*", page_index, page_size, condition, order_by="sort_index desc", params=params)
 
-        for act_prize in act_prize_page_list:
-            try:
-                if act_prize["prize_detail"]:
-                    act_prize["prize_detail"] = self.json_loads(act_prize["prize_detail"])
-                else:
-                    act_prize["prize_detail"] = []
-            except Exception as ex:
-                act_prize["prize_detail"] = []
+        # for act_prize in act_prize_page_list:
+        #     try:
+        #         act_prize["prize_detail"] = self.json_loads(act_prize["prize_detail"]) if act_prize["prize_detail"] else []
+        #     except Exception as ex:
+        #         act_prize["prize_detail"] = []
 
         page_info = PageInfo(page_index, page_size, total, act_prize_page_list)
 
@@ -63,32 +60,32 @@ class PrizeListHandler(SevenBaseHandler):
 
 class SyncPayOrderHandler(TopBaseHandler):
     """
-    @description: 用户支付订单提交（业务各自实现）
+    :description: 用户支付订单提交（业务各自实现）
     """
     def get_async(self):
         """
-        @description: 用户支付订单提交（业务各自实现）
-        @param {*}
-        @return {*}
-        @last_editors: HuangJingCan
+        :description: 用户支付订单提交（业务各自实现）
+        :param 
+        :return 
+        :last_editors: HuangJingCan
         """
         pass
 
 
 class UserPrizeListHandler(SevenBaseHandler):
     """
-    @description: 获取用户奖品列表
+    :description: 获取用户奖品列表
     """
     @filter_check_params("act_id")
     def get_async(self):
         """
-        @description: 获取用户奖品列表
-        @param act_id：活动id
-        @return status：状态
-        @param page_index：页索引
-        @param page_size：页大小
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 获取用户奖品列表
+        :param act_id：活动id
+        :return status：状态
+        :param page_index：页索引
+        :param page_size：页大小
+        :return: 
+        :last_editors: HuangJingCan
         """
         app_id = self.get_taobao_param().source_app_id
         open_id = self.get_taobao_param().open_id
@@ -111,25 +108,25 @@ class UserPrizeListHandler(SevenBaseHandler):
         self.reponse_json_success(page_info)
 
 
-class SubmitPrizeOrder(SevenBaseHandler):
+class SubmitPrizeOrderHandler(SevenBaseHandler):
     """
-    @description: 奖品订单提交
+    :description: 奖品订单提交
     """
     @filter_check_params("act_id")
     def get_async(self):
         """
-        @description: 奖品订单提交
-        @param act_id：活动id
-        @param login_token：登录令牌
-        @param real_name：用户名
-        @param telephone：联系电话
-        @param province：所在省
-        @param city：所在市
-        @param county：所在区
-        @param street：所在街道
-        @param address：收货地址
-        @return 
-        @last_editors: HuangJingCan
+        :description: 奖品订单提交
+        :param act_id：活动id
+        :param login_token：登录令牌
+        :param real_name：用户名
+        :param telephone：联系电话
+        :param province：所在省
+        :param city：所在市
+        :param county：所在区
+        :param street：所在街道
+        :param address：收货地址
+        :return 
+        :last_editors: HuangJingCan
         """
         app_id = self.get_taobao_param().source_app_id
         open_id = self.get_taobao_param().open_id
@@ -181,24 +178,27 @@ class SubmitPrizeOrder(SevenBaseHandler):
 
         prize_order.id = prize_order_model.add_entity(prize_order)
 
-        prize_roster_model.update_table("prize_order_id=%s,prize_order_no=%s", "act_id=%s and open_id=%s and prize_order_id=0", params=[prize_order.id, prize_order.order_no, act_id, open_id])
+        update_sql = "prize_order_id=%s,prize_order_no=%s"
+        where = "act_id=%s and open_id=%s and prize_order_id=0"
+        params = [prize_order.id, prize_order.order_no, act_id, open_id]
+        prize_roster_model.update_table(update_sql, where, params)
 
         self.reponse_json_success()
 
 
 class PrizeOrderHandler(SevenBaseHandler):
     """
-    @description: 用户订单列表
+    :description: 用户订单列表
     """
     @filter_check_params("act_id")
     def get_async(self):
         """
-        @description: 用户订单列表
-        @param act_id：活动id
-        @param page_index：页索引
-        @param page_size：页大小
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 用户订单列表
+        :param act_id：活动id
+        :param page_index：页索引
+        :param page_size：页大小
+        :return: PageInfo
+        :last_editors: HuangJingCan
         """
         app_id = self.get_taobao_param().source_app_id
         open_id = self.get_taobao_param().open_id
@@ -209,7 +209,7 @@ class PrizeOrderHandler(SevenBaseHandler):
 
         prize_order_model = PrizeOrderModel()
         prize_roster_model = PrizeRosterModel()
-        prize_order_list_dict, total = prize_order_model.get_dict_page_list("*", page_index, page_size, "open_id=%s and act_id=%s ", "", "create_date desc", [open_id, act_id])
+        prize_order_list_dict, total = prize_order_model.get_dict_page_list("*", page_index, page_size, "open_id=%s and act_id=%s", "", "create_date desc", [open_id, act_id])
         if prize_order_list_dict:
             prize_order_id_list = [i["id"] for i in prize_order_list_dict]
             prize_order_ids = str(prize_order_id_list).strip('[').strip(']')
@@ -224,15 +224,15 @@ class PrizeOrderHandler(SevenBaseHandler):
 
 class RosterNoticeHandler(SevenBaseHandler):
     """
-    @description: 中奖通告
+    :description: 中奖通告
     """
     @filter_check_params("act_id")
     def get_async(self):
         """
-        @description: 中奖通告
-        @param act_id：活动id
-        @return 列表
-        @last_editors: HuangJingCan
+        :description: 中奖通告
+        :param act_id：活动id
+        :return 列表
+        :last_editors: HuangJingCan
         """
         act_id = int(self.get_param("act_id", 0))
 
