@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-05-19 11:33:16
-:LastEditTime: 2021-02-02 16:50:15
+:LastEditTime: 2021-02-03 12:56:32
 :LastEditors: HuangJingCan
 :description: 任务处理
 """
@@ -1007,7 +1007,7 @@ class BuyGoodsHandler(TaskBaseHandler):
         # self.logger_info.info(str(order_data) + "【订单列表】")
 
         pay_order_model = PayOrderModel()
-        pay_order_list = pay_order_model.get_list("app_id=%s and open_id=%s and act_id=%s", params=[app_id, open_id, act_id])
+        pay_order_list = pay_order_model.get_list("app_id=%s and open_id=%s and act_id=%s", order_by="id desc", params=[app_id, open_id, act_id])
 
         pay_order_id_list = []
         for item in pay_order_list:
@@ -1121,7 +1121,7 @@ class BuyGoodsHandler(TaskBaseHandler):
                     coin_order_model.add_entity(coin_order)
 
         except Exception as ex:
-            self.logger_info.info(str(all_sub_order_list) + "【任务订单列表】" + str(ex))
+            # self.logger_info.info(str(all_sub_order_list) + "【任务订单列表】" + str(ex))
             return self.reponse_json_error('Error', '任务获取订单失败', str(ex))
 
         is_black = self.check_black(user_info, act_dict, all_goods_order_list)
