@@ -1,69 +1,99 @@
 # -*- coding: utf-8 -*-
 """
-@Author: HuangJingCan
-@Date: 2020-05-19 11:33:16
-@LastEditTime: 2020-12-24 09:44:35
-@LastEditors: HuangJingCan
-@Description: 用户处理
+:Author: HuangJingCan
+:Date: 2020-05-19 11:33:16
+:LastEditTime: 2021-01-27 16:40:23
+:LastEditors: HuangJingCan
+:description: 用户处理
 """
 from seven_cloudapp.handlers.seven_base import *
+from seven_cloudapp.libs.customize.seven import *
 
 from seven_cloudapp.models.seven_model import PageInfo
 from seven_cloudapp.models.behavior_model import *
 
-from seven_cloudapp.models.db_models.user.user_info_model import *
 from seven_cloudapp.models.db_models.act.act_info_model import *
+from seven_cloudapp.models.db_models.user.user_base_model import *
+from seven_cloudapp.models.db_models.user.user_info_model import *
+from seven_cloudapp.models.db_models.user.user_blacklist_model import *
 from seven_cloudapp.models.db_models.machine.machine_info_model import *
 from seven_cloudapp.models.db_models.machine.machine_value_model import *
-from seven_cloudapp.models.db_models.user.user_blacklist_model import *
-
-from seven_cloudapp.libs.customize.seven import *
+from seven_cloudapp.models.db_models.gear.gear_value_model import *
 
 
 class LoginHandler(SevenBaseHandler):
     """
-    @description: 登录处理
+    :description: 登录处理
     """
     @filter_check_params("act_id,open_id")
     def get_async(self):
         """
-        @description: 登录日志入库
-        @param owner_open_id：应用拥有者唯一标识
-        @param act_id：活动id
-        @return: dict
-        @last_editors: HuangJingCan
+        :description: 登录日志入库
+        :param owner_open_id：应用拥有者唯一标识
+        :param act_id:活动id
+        :param owner_open_id:owner_open_id
+        :param is_machine:是否机台
+        :param is_gear:是否价格挡位
+        :return: dict
+        :last_editors: HuangJingCan
         """
         open_id = self.get_taobao_param().open_id
         user_nick = self.get_taobao_param().user_nick
         app_id = self.get_taobao_param().source_app_id
         owner_open_id = self.get_param("owner_open_id")
         act_id = int(self.get_param("act_id", 0))
+        # 0-没关联机台或者价格挡位，1-关联机台，2-关联价格挡位
+        is_machine_gear = config.get_value("is_machine_gear", 0)
+
+        act_dict = ActInfoModel().get_dict_by_id(act_id)
+        if not act_dict:
+            return self.reponse_json_error("NoAct", "对不起，活动不存在")
+
+        if is_machine_gear in (1, 2):
+            machine_dict_list = MachineInfoModel().get_dict_list("act_id=%s", params=[act_id])
+            if not machine_dict_list:
+                return self.reponse_json_error("NoMachine", "对不起，盲盒不存在")
+
+        # 用户基础表
+        user_base = UserBaseModel().get_entity("open_id=%s", params=[open_id])
 
         user_info_model = UserInfoModel()
         user_info = user_info_model.get_entity("act_id=%s and open_id=%s", params=[act_id, open_id])
 
-        act_info = ActInfoModel().get_entity("id=%s", params=act_id)
-        if not act_info:
-            return self.reponse_json_error("NoAct", "对不起，活动不存在")
-
         if not user_info:
             user_info = UserInfo()
             user_info.open_id = open_id
             user_info.act_id = act_id
             user_info.app_id = app_id
             user_info.is_new = 1
-            user_info.user_nick = user_nick
+            if user_base:
+                user_info.user_nick = user_base.user_nick
+                user_info.avatar = user_base.avatar
+            if user_nick:
+                user_info.user_nick = user_nick
             user_info.create_date = self.get_now_datetime()
             user_info.modify_date = self.get_now_datetime()
             user_info.login_token = SevenHelper.get_random(16, 1)
             user_info.id = user_info_model.add_entity(user_info)
         else:
+            if user_base:
+                user_info.user_nick = user_base.user_nick
+                user_info.avatar = user_base.avatar
             if user_nick:
                 user_info.user_nick = user_nick
             user_info.modify_date = self.get_now_datetime()
             user_info.login_token = SevenHelper.get_random(16, 1)
             user_info.is_new = 0
-            user_info_model.update_entity(user_info, "modify_date,login_token,is_new,user_nick")
+            user_info_model.update_entity(user_info, "modify_date,login_token,is_new,user_nick,avatar")
+
+        user_info_dict = user_info.__dict__
+
+        if is_machine_gear == 1:
+            machine_value_list = MachineValueModel().get_dict_list("act_id=%s and open_id=%s", params=[act_id, open_id])
+            user_info_dict["machine_value_list"] = machine_value_list
+        elif is_machine_gear == 2:
+            gear_value_list = GearValueModel().get_dict_list("act_id=%s and open_id=%s", params=[act_id, open_id])
+            user_info_dict["gear_value_list"] = gear_value_list
 
         behavior_model = BehaviorModel()
         # 访问次数
@@ -74,93 +104,67 @@ class LoginHandler(SevenBaseHandler):
             # 新增用户数
             behavior_model.report_behavior_log(app_id, act_id, open_id, owner_open_id, 'VisitManCountEveryDayIncrease', 1)
 
-        self.reponse_json_success(user_info)
+        self.reponse_json_success(user_info_dict)
 
 
-class LoginByMachineHandler(SevenBaseHandler):
+class UserBaseHandler(SevenBaseHandler):
     """
-    @description: 登录处理（包含机台信息）
+    :description: 用户信息导入到用户基础表
     """
-    @filter_check_params("act_id,open_id")
+    @filter_check_params("key")
     def get_async(self):
         """
-        @description: 登录日志入库
-        @param owner_open_id：应用拥有者唯一标识
-        @param act_id：活动id
-        @return: dict
-        @last_editors: HuangJingCan
+        :description: 用户信息导入到用户基础表
+        :param self：self
+        :return: 
+        :last_editors: HuangJingCan
         """
-        open_id = self.get_taobao_param().open_id
-        user_nick = self.get_taobao_param().user_nick
-        app_id = self.get_taobao_param().source_app_id
-        owner_open_id = self.get_param("owner_open_id")
-        act_id = int(self.get_param("act_id", 0))
+        key = self.get_param("key")
+        if key != "gao7gao8":
+            return self.reponse_json_error_params()
 
+        page_size = 100
+        user_base_model = UserBaseModel()
         user_info_model = UserInfoModel()
-        user_info = user_info_model.get_entity("act_id=%s and open_id=%s", params=[act_id, open_id])
+        record_count = user_info_model.get_total("is_auth=1")
 
-        act_info = ActInfoModel().get_entity("id=%s", params=act_id)
-        if not act_info:
-            return self.reponse_json_error("NoAct", "对不起，活动不存在")
+        page_count = SevenHelper.get_page_count(page_size, record_count)
+        for page_index in range(0, page_count):
+            page_list, row_count = user_info_model.get_page_list("*", page_index, page_size, "is_auth=1")
+            for page in page_list:
+                print(page.id)
+                user_base = user_base_model.get_entity("open_id=%s", params=page.open_id)
+                if not user_base:
+                    user_base = UserBase()
+                    user_base.is_auth = 1
+                    user_base.open_id = page.open_id
+                    user_base.user_nick = page.user_nick
+                    user_base.avatar = page.avatar
+                    user_base.user_state = page.user_state
+                    user_base.relieve_date = page.relieve_date
+                    user_base.create_date = page.create_date
+                    user_base.modify_date = page.modify_date
+                    user_base_model.add_entity(user_base)
 
-        machine_info_model = MachineInfoModel()
-        machine_info_list = machine_info_model.get_list("act_id=%s", params=[act_id])
-        if not machine_info_list:
-            return self.reponse_json_error("NoMachine", "对不起，机台不存在")
-
-        if not user_info:
-            user_info = UserInfo()
-            user_info.open_id = open_id
-            user_info.act_id = act_id
-            user_info.app_id = app_id
-            user_info.is_new = 1
-            user_info.user_nick = user_nick
-            user_info.create_date = self.get_now_datetime()
-            user_info.modify_date = self.get_now_datetime()
-            user_info.login_token = SevenHelper.get_random(16, 1)
-            user_info.id = user_info_model.add_entity(user_info)
-        else:
-            if user_nick:
-                user_info.user_nick = user_nick
-            user_info.modify_date = self.get_now_datetime()
-            user_info.login_token = SevenHelper.get_random(16, 1)
-            user_info.is_new = 0
-            user_info_model.update_entity(user_info, "modify_date,login_token,is_new,user_nick")
-
-        machine_value_model = MachineValueModel()
-        machine_value_list = machine_value_model.get_dict_list("open_id=%s", params=open_id)
-        user_info_dict = user_info.__dict__
-        user_info_dict["machine_value_list"] = machine_value_list
-
-        behavior_model = BehaviorModel()
-        # 访问次数
-        behavior_model.report_behavior(app_id, act_id, open_id, owner_open_id, 'VisitCountEveryDay', 1)
-        # 访问人数
-        behavior_model.report_behavior(app_id, act_id, open_id, owner_open_id, 'VisitManCountEveryDay', 1)
-        if user_info.is_new == 1:
-            # 新增用户数
-            behavior_model.report_behavior(app_id, act_id, open_id, owner_open_id, 'VisitManCountEveryDayIncrease', 1)
-
-        self.reponse_json_success(user_info_dict)
+        self.reponse_json_success(self.get_now_datetime())
 
 
 class UserHandler(SevenBaseHandler):
     """
-    @description: 更新用户信息
+    :description: 更新用户信息
     """
     @filter_check_params("act_id")
     def get_async(self):
         """
-        @description: 更新用户信息
-        @param avatar：头像
-        @param act_id：活动id
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 更新用户信息
+        :param avatar：头像
+        :param act_id：活动id
+        :return: 
+        :last_editors: HuangJingCan
         """
         try:
             open_id = self.get_taobao_param().open_id
             user_nick = self.get_taobao_param().user_nick
-            source_app_id = self.get_taobao_param().source_app_id
             avatar = self.get_param("avatar")
             act_id = int(self.get_param("act_id", 0))
 
@@ -176,6 +180,29 @@ class UserHandler(SevenBaseHandler):
             user_info.modify_date = self.get_now_datetime()
             user_info_model.update_entity(user_info)
 
+            # 用户基础表
+            user_base_model = UserBaseModel()
+            user_base = user_base_model.get_entity("open_id=%s", params=[open_id])
+            if user_base:
+                if user_nick:
+                    user_base.user_nick = user_nick
+                if avatar:
+                    user_base.avatar = avatar
+                user_base.modify_date = self.get_now_datetime()
+                user_base_model.update_entity(user_base, "modify_date,avatar,user_nick")
+            else:
+                user_base = UserBase()
+                user_base.open_id = open_id
+                if user_nick:
+                    user_base.user_nick = user_nick
+                if avatar:
+                    user_base.avatar = avatar
+                user_base.is_auth = 1
+                user_base.user_state = 0
+                user_base.create_date = self.get_now_datetime()
+                user_base.modify_date = self.get_now_datetime()
+                user_base_model.add_entity(user_base)
+
             self.reponse_json_success("更新成功")
         except Exception as ex:
             self.reponse_json_error("Error", "更新失败")
@@ -183,16 +210,16 @@ class UserHandler(SevenBaseHandler):
 
 class SubmitUnbindHandler(SevenBaseHandler):
     """
-    @description: 提交黑名单解封申请
+    :description: 提交黑名单解封申请
     """
     @filter_check_params("act_id")
     def get_async(self):
         """
-        @description: 提交黑名单解封申请
-        @param {act_id:活动id}
-        @param {reason:解封理由}
-        @return {*}
-        @last_editors: HuangJianYi
+        :description: 提交黑名单解封申请
+        :param {act_id:活动id}
+        :param {reason:解封理由}
+        :return {*}
+        :last_editors: HuangJianYi
         """
         app_id = self.get_taobao_param().source_app_id
         open_id = self.get_taobao_param().open_id
@@ -221,15 +248,15 @@ class SubmitUnbindHandler(SevenBaseHandler):
 
 class GetUnbindApplyandler(SevenBaseHandler):
     """
-    @description: 获取黑名单解封申请记录
+    :description: 获取黑名单解封申请记录
     """
     @filter_check_params("act_id")
     def get_async(self):
         """
-        @description: 获取黑名单解封申请记录
-        @param {act_id:活动id}
-        @return {*}
-        @last_editors: HuangJianYi
+        :description: 获取黑名单解封申请记录
+        :param {act_id:活动id}
+        :return {*}
+        :last_editors: HuangJianYi
         """
         app_id = self.get_taobao_param().source_app_id
         open_id = self.get_taobao_param().open_id
