@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
-@Author: CaiYouBin
-@Date: 2020-06-01 14:07:23
-@LastEditTime: 2020-12-24 16:13:35
-@LastEditors: HuangJingCan
-@Description: 商品相关
+:Author: CaiYouBin
+:Date: 2020-06-01 14:07:23
+:LastEditTime: 2020-12-29 13:40:42
+:LastEditors: HuangJingCan
+:description: 商品相关
 """
 from seven_cloudapp.handlers.top_base import *
 
@@ -16,18 +16,18 @@ from seven_cloudapp.models.db_models.recommend.recommend_goods_model import *
 
 class GoodsListHandler(TopBaseHandler):
     """
-    @description: 导入商品列表（获取当前会话用户出售中的商品列表）
+    :description: 导入商品列表（获取当前会话用户出售中的商品列表）
     """
     def get_async(self):
         """
-        @description: 导入商品列表（获取当前会话用户出售中的商品列表）
-        @param goods_name：商品名称
-        @param order_tag：order_tag
-        @param order_by：排序类型
-        @param page_index：页索引
-        @param page_size：页大小
-        @return: 列表
-        @last_editors: HuangJingCan
+        :description: 导入商品列表（获取当前会话用户出售中的商品列表）
+        :param goods_name：商品名称
+        :param order_tag：order_tag
+        :param order_by：排序类型
+        :param page_index：页索引
+        :param page_size：页大小
+        :return: 列表
+        :last_editors: HuangJingCan
         """
         access_token = self.get_taobao_param().access_token
         goods_name = self.get_param("goods_name")
@@ -41,38 +41,41 @@ class GoodsListHandler(TopBaseHandler):
 
 class GoodsListByGoodsIDHandler(TopBaseHandler):
     """
-    @description: 根据商品id获取商品列表
+    :description: 根据商品id获取商品列表
     """
     @filter_check_params("goods_ids")
     def get_async(self):
         """
-        @description: 根据商品id获取商品列表
-        @param goods_id：商品id
-        @param is_check_exist：是否存在
-        @return: list
-        @last_editors: HuangJingCan
+        :description: 根据商品id获取商品列表
+        :param goods_id：商品id
+        :param is_check_exist：是否存在
+        :return: list
+        :last_editors: HuangJingCan
         """
         access_token = self.get_taobao_param().access_token
         goods_ids = self.get_param("goods_ids")
 
         resp = self.get_goods_list_for_goodsids(goods_ids, access_token)
 
+        if "error_message" in resp.keys():
+            return self.reponse_json_error("Error", resp["error_message"])
+
         self.reponse_json_success(resp)
 
 
 class GoodsInfoHandler(TopBaseHandler):
     """
-    @description: 获取商品信息
+    :description: 获取商品信息
     """
     @filter_check_params("goods_id")
     def get_async(self):
         """
-        @description: 获取商品信息
-        @param goods_id：商品id
-        @param machine_id：机台id
-        @param is_check_exist：是否存在
-        @return: 商品信息
-        @last_editors: HuangJingCan
+        :description: 获取商品信息
+        :param goods_id：商品id
+        :param machine_id：机台id
+        :param is_check_exist：是否存在
+        :return: 商品信息
+        :last_editors: HuangJingCan
         """
         access_token = self.get_taobao_param().access_token
         num_iid = self.get_param("goods_id")
@@ -90,16 +93,16 @@ class GoodsInfoHandler(TopBaseHandler):
 
 class GoodsCheckHandler(TopBaseHandler):
     """
-    @description: 校验商品
+    :description: 校验商品
     """
     @filter_check_params("goods_id,act_id")
     def get_async(self):
         """
-        @description: 校验商品
-        @param goods_id：商品id
-        @param act_id：活动id
-        @return: 商品信息
-        @last_editors: HuangJingCan
+        :description: 校验商品
+        :param goods_id：商品id
+        :param act_id：活动id
+        :return: 商品信息
+        :last_editors: HuangJingCan
         """
         access_token = self.get_taobao_param().access_token
         num_iid = self.get_param("goods_id")
@@ -117,20 +120,18 @@ class GoodsCheckHandler(TopBaseHandler):
 
 class GetCouponDetails(TopBaseHandler):
     """
-    @description: 获取优惠券详情信息
+    :description: 获取优惠券详情信息
     """
     def get_async(self):
         """
-        @description: 获取优惠券详情信息
-        @param right_ename:奖池ID
-        @return: dict
-        @last_editors: LaiKaiXiang
+        :description: 获取优惠券详情信息
+        :param right_ename:奖池ID
+        :return: dict
+        :last_editors: LaiKaiXiang
         """
         right_ename = self.get_param("right_ename")
 
-        resp = self.get_coupon_details(right_ename)
-
-        self.reponse_json_success(resp)
+        self.get_coupon_details(right_ename)
 
 
 class RecommendGoodsHandler(SevenBaseHandler):
@@ -140,14 +141,14 @@ class RecommendGoodsHandler(SevenBaseHandler):
     @filter_check_params("act_id,app_id")
     def post_async(self):
         """
-        @description: 保存爆品推荐
-        @param app_id：app_id
-        @param act_id：act_id
-        @param goods_ids：推荐商品id(逗号,分隔)
-        @param goods_list：推荐商品列表
-        @param is_open：是否开启
-        @return reponse_json_success
-        @last_editors: LaiKaiXiang
+        :description: 保存爆品推荐
+        :param app_id：app_id
+        :param act_id：act_id
+        :param goods_ids：推荐商品id(逗号,分隔)
+        :param goods_list：推荐商品列表
+        :param is_open：是否开启
+        :return reponse_json_success
+        :last_editors: LaiKaiXiang
         """
         act_id = int(self.get_param("act_id", 0))
         app_id = self.get_param("app_id")
@@ -187,10 +188,10 @@ class RecommendGoodsInfoHandler(SevenBaseHandler):
     @filter_check_params("act_id")
     def get_async(self):
         """
-        @description: 获取爆品推荐列表
-        @param act_id：act_id
-        @return list
-        @last_editors: LaiKaiXiang
+        :description: 获取爆品推荐列表
+        :param act_id：act_id
+        :return list
+        :last_editors: LaiKaiXiang
         """
         act_id = int(self.get_param("act_id", 0))
 
