@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
-@Author: HuangJingCan
-@Date: 2020-06-02 13:44:17
-@LastEditTime: 2020-12-24 16:14:41
-@LastEditors: HuangJingCan
-@Description: 奖品相关
+:Author: HuangJingCan
+:Date: 2020-06-02 13:44:17
+:LastEditTime: 2021-01-18 09:31:07
+:LastEditors: HuangJingCan
+:description: 奖品相关
 """
 from copy import deepcopy
 from seven_cloudapp.handlers.seven_base import *
@@ -23,18 +23,18 @@ from seven_cloudapp.models.db_models.throw.throw_goods_model import *
 
 class PrizeListHandler(SevenBaseHandler):
     """
-    @description: 奖品列表
+    :description: 奖品列表
     """
     @filter_check_params("act_id")
     def get_async(self):
         """
-        @description: 奖品列表
-        @param page_index：页索引
-        @param page_size：页大小
-        @param act_id：活动id
-        @param ascription_type：奖品归属（0-活动奖品1-任务奖品）
-        @return: PageInfo
-        @last_editors: HuangJingCan
+        :description: 奖品列表
+        :param page_index：页索引
+        :param page_size：页大小
+        :param act_id：活动id
+        :param ascription_type：奖品归属（0-活动奖品1-任务奖品）
+        :return: PageInfo
+        :last_editors: HuangJingCan
         """
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 10))
@@ -112,16 +112,16 @@ class PrizeListHandler(SevenBaseHandler):
 
 class PrizeHandler(SevenBaseHandler):
     """
-    @description: 奖品保存
+    :description: 奖品保存
     """
     @filter_check_params("app_id,act_id")
     def post_async(self):
         """
-        @description: 奖品保存
-        @param prize_id：奖品id
-        @param prize_type 奖品类型（1实物2店铺商品3优惠券4参与奖）
-        @return: reponse_json_success
-        @last_editors: LaiKaiXiang
+        :description: 奖品保存
+        :param prize_id：奖品id
+        :param prize_type 奖品类型（1实物2店铺商品3优惠券4参与奖）
+        :return: reponse_json_success
+        :last_editors: LaiKaiXiang
         """
         prize_id = int(self.get_param("prize_id", 0))
         act_id = int(self.get_param("act_id", 0))
@@ -167,14 +167,13 @@ class PrizeHandler(SevenBaseHandler):
 
         act_prize_model = ActPrizeModel()
         act_prize = None
-        old_act_prize = None
         if prize_id > 0:
             act_prize = act_prize_model.get_entity_by_id(prize_id)
 
         if not act_prize:
             act_prize = ActPrize()
-        else:
-            old_act_prize = deepcopy(act_prize)
+
+        old_act_prize = deepcopy(act_prize)
 
         act_prize.act_id = act_id
         act_prize.award_id = award_id
@@ -240,15 +239,15 @@ class PrizeHandler(SevenBaseHandler):
 
 class PrizeDelHandler(SevenBaseHandler):
     """
-    @description: 删除奖品
+    :description: 删除奖品
     """
     @filter_check_params("prize_id")
     def get_async(self):
         """
-        @description: 删除奖品
-        @param prize_id：奖品id
-        @return: reponse_json_success
-        @last_editors: HuangJingCan
+        :description: 删除奖品
+        :param prize_id：奖品id
+        :return: reponse_json_success
+        :last_editors: HuangJingCan
         """
         prize_id = int(self.get_param("prize_id", 0))
 
@@ -262,50 +261,18 @@ class PrizeDelHandler(SevenBaseHandler):
         self.reponse_json_success()
 
 
-class PrizeDelByThrowHandler(SevenBaseHandler):
-    """
-    @description: 删除奖品
-    """
-    @filter_check_params("prize_id")
-    def get_async(self):
-        """
-        @description: 删除奖品
-        @param prize_id：奖品id
-        @return: reponse_json_success
-        @last_editors: HuangJingCan
-        """
-        prize_id = int(self.get_param("prize_id", 0))
-
-        if prize_id <= 0:
-            return self.reponse_json_error_params()
-
-        act_prize_model = ActPrizeModel()
-        act_prize = act_prize_model.get_entity("id=%s", params=prize_id)
-
-        if not act_prize:
-            return self.reponse_json_success()
-
-        act_prize_model.del_entity("id=%s", prize_id)
-
-        ThrowBaseHandler().throw_goods_update(act_prize.act_id, act_prize.goods_id)
-
-        self.create_operation_log(OperationType.delete.value, "act_prize_tb", "PrizeDelByThrowHandler", None, prize_id)
-
-        self.reponse_json_success()
-
-
 class PrizeReleaseHandler(SevenBaseHandler):
     """
-    @description: 上下架奖品
+    :description: 上下架奖品
     """
     @filter_check_params("prize_id")
     def get_async(self):
         """
-        @description: 上下架奖品
-        @param prize_id：奖品id
-        @param is_release：0-下架，1-上架
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 上下架奖品
+        :param prize_id：奖品id
+        :param is_release：0-下架，1-上架
+        :return: 
+        :last_editors: HuangJingCan
         """
         prize_id = int(self.get_param("prize_id", 0))
         is_release = int(self.get_param("is_release", 0))
@@ -321,15 +288,15 @@ class PrizeReleaseHandler(SevenBaseHandler):
 
 class CheckRightEnameHandler(SevenBaseHandler):
     """
-    @description: 判断奖品里面有没有添加这张优惠券
+    :description: 判断奖品里面有没有添加这张优惠券
     """
     @filter_check_params("right_ename")
     def get_async(self):
         """
-        @description: 判断奖品里面有没有添加这张优惠券
-        @param right_ename：优惠券标识
-        @return reponse_json_success
-        @last_editors: HuangJingCan
+        :description: 判断奖品里面有没有添加这张优惠券
+        :param right_ename：优惠券标识
+        :return reponse_json_success
+        :last_editors: HuangJingCan
         """
         right_ename = self.get_param("right_ename")
 
