@@ -2,14 +2,16 @@
 """
 :Author: HuangJingCan
 :Date: 2020-05-12 20:04:54
-:LastEditTime: 2021-01-29 13:45:05
+:LastEditTime: 2021-02-06 10:25:57
 :LastEditors: HuangJingCan
 :description: 用户相关
 """
 from seven_cloudapp.handlers.seven_base import *
+from seven_cloudapp.libs.customize.seven import *
+from seven_cloudapp.libs.customize.oss2help import *
 
+from seven_cloudapp.models.enum import *
 from seven_cloudapp.models.seven_model import *
-
 from seven_cloudapp.models.db_models.app.app_info_model import *
 from seven_cloudapp.models.db_models.login.login_log_model import *
 from seven_cloudapp.models.db_models.user.user_info_model import *
@@ -17,9 +19,7 @@ from seven_cloudapp.models.db_models.machine.machine_value_model import *
 from seven_cloudapp.models.db_models.user.user_blacklist_model import *
 from seven_cloudapp.models.db_models.lottery.lottery_value_log_model import *
 from seven_cloudapp.models.db_models.act.act_info_model import *
-
-from seven_cloudapp.libs.customize.seven import *
-from seven_cloudapp.libs.customize.oss2help import *
+from seven_cloudapp.models.db_models.coin.coin_order_model import *
 
 
 class LoginHandler(SevenBaseHandler):
@@ -386,7 +386,10 @@ class LotteryValueHandler(SevenBaseHandler):
             return self.reponse_json_error_params()
 
         history_value = 0
-        history_value = user_info.lottery_value
+        if act_dict['currency_type'] == 1:
+            history_value = user_info.lottery_value
+        elif act_dict['currency_type'] == 2:
+            history_value = user_info.surplus_integral
         if history_value != current_value:
             update_sql = ""
             if act_dict['currency_type'] == 1:
