@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-08-12 09:06:24
-:LastEditTime: 2021-01-22 18:55:00
+:LastEditTime: 2021-02-03 12:56:16
 :LastEditors: HuangJingCan
 :description: 淘宝top接口基础类
 """
@@ -354,7 +354,7 @@ class TopBaseHandler(SevenBaseHandler):
             req.description = description
             shop_info = self.get_shop(access_token)
 
-            if isfirst == 1:
+            if isfirst == 1 and shop_info:
                 app_name = shop_info["shop_seller_get_response"]["shop"]["title"] + name_ending
             else:
                 app_name = name
@@ -519,7 +519,7 @@ class TopBaseHandler(SevenBaseHandler):
             else:
                 return resp["vas_subscribe_get_response"]["article_user_subscribes"]["article_user_subscribe"][0]["deadline"]
         except Exception as ex:
-            self.logger_info.info("get_dead_date:" + str(ex))
+            # self.logger_info.info("get_dead_date:" + str(ex))
             return config.get_value("test_dead_date")
 
     def get_token(self):
