@@ -21,6 +21,7 @@ class InviteLog:
         self.app_id = ""  # 应用标识
         self.act_id = 0  # 活动标识
         self.open_id = ""  # 邀请人OpenID
+        self.invite_user_nick = ""  # 受邀人昵称
         self.invite_open_id = ""  # 受邀人OpenID
         self.invite_avatar = ""  # 受邀人头像
         self.is_handle = 0  # 是否处理（1处理0未处理）
@@ -29,7 +30,7 @@ class InviteLog:
 
     @classmethod
     def get_field_list(self):
-        return ['id', 'app_id', 'act_id', 'open_id', 'invite_open_id', 'invite_avatar', 'is_handle', 'create_date', 'create_day']
+        return ['id', 'app_id', 'act_id', 'open_id', 'invite_user_nick', 'invite_open_id', 'invite_avatar', 'is_handle', 'create_date', 'create_day']
         
     @classmethod
     def get_primary_key(self):
